@@ -1,7 +1,7 @@
 # Copyright 2019 Cognite AS
 
-from cognite.seismic._api import BinaryHeader, Geometry, TextHeader
 from cognite.seismic._api_client import CogniteSeismicClient
+from cognite.seismic.data_classes.api_types import *
 
 from ._version import get_version
 
