@@ -3,6 +3,7 @@ from typing import *
 
 from cognite.seismic._api.api import API
 from cognite.seismic._api.utility import LineRange, MaybeString, Metadata, get_identifier, get_search_spec
+from cognite.seismic.data_classes.api_types import BinaryHeader, Geometry, Seismic, TextHeader, VolumeDef
 from google.protobuf.struct_pb2 import Struct
 from google.protobuf.wrappers_pb2 import Int32Value as i32
 from google.protobuf.wrappers_pb2 import StringValue
@@ -16,139 +17,10 @@ if not os.getenv("READ_THE_DOCS"):
         DeleteSeismicResponse,
         VolumeRequest,
     )
-    from cognite.seismic.protos.v1.seismic_service_datatypes_pb2 import (
-        Seismic,
-        OptionalMap,
-        Identifier,
-        TextHeader as pTextHeader,
-        BinaryHeader as pBinaryHeader,
-    )
-    from cognite.seismic.protos.types_pb2 import Geometry as GeometryProto, CRS as CRSProto, Wkt, GeoJson
+    from cognite.seismic.protos.v1.seismic_service_datatypes_pb2 import OptionalMap, Identifier
+    from cognite.seismic.protos.types_pb2 import CRS as CRSProto, Wkt, GeoJson
 else:
-    from cognite.seismic._api.shims import Seismic, Geometry as GeometryProto, Identifier
-
-
-class VolumeDef:
-    def __init__(self, volumedef: str):
-        self.volumedef = volumedef
-
-
-class Geometry:
-    """Represents a CRS + shape, in either a WKT format or a GeoJSON."""
-
-    def __init__(self, crs: str, *, geojson: Union[Struct, None] = None, wkt: Union[str, None] = None):
-        if (geojson is None) and (wkt is None):
-            raise Exception("You must specify one of: geojson, wkt")
-        if (geojson is not None) and (wkt is not None):
-            raise Exception("You must specify either of: geojson, wkt")
-        self.crs = crs
-        self.geojson = geojson
-        self.wkt = wkt
-
-    def to_proto(self):
-        crs_proto = CRSProto(crs=self.crs)
-        if self.geojson is not None:
-            return GeometryProto(crs=crs_proto, geo=GeoJson(json=self.geojson))
-        if self.wkt is not None:
-            return GeometryProto(crs=crs_proto, wkt=Wkt(geometry=self.wkt))
-
-
-class TextHeader:
-    """A representation of text headers used to create or edit existing headers."""
-
-    def __init__(self, *, header: MaybeString = None, raw_header: MaybeString = None):
-        """Create a text header.
-
-        Specify either header or raw_header.
-        
-        Args:
-            header (String | None): The text content of a header
-            raw_header (String | None): The raw bytes of a header
-        """
-        self.header = header
-        self.raw_header = raw_header
-
-    def into_proto(self):
-        return pTextHeader(header=self.header, raw_header=self.raw_header)
-
-
-class BinaryHeader:
-    """A representation of binary headers used to create or edit existing headers.
-    
-    BinaryHeader.FIELDS contains the list of valid fields. to set after the object is constructed.
-    """
-
-    FIELDS = [
-        "traces",
-        "trace_data_type",
-        "fixed_length_traces",
-        "segy_revision",
-        "auxtraces",
-        "interval",
-        "interval_original",
-        "samples",
-        "samples_original",
-        "ensemble_fold",
-        "vertical_sum",
-        "trace_type_sorting_code",
-        "sweep_type_code",
-        "sweep_frequency_start",
-        "sweep_frequency_end",
-        "sweep_length",
-        "sweep_channel",
-        "sweep_taper_start",
-        "sweep_taper_end",
-        "sweep_taper_type",
-        "correlated_traces",
-        "amplitude_recovery",
-        "original_measurement_system",
-        "impulse_signal_polarity",
-        "vibratory_polarity_code",
-    ]
-
-    def __init__(self, *args, raw_header: Union[bytes, None] = None, **kwargs):
-        """Initialize.
-        
-        Args:
-            *args (int): An optional list of arguments. The fields are assigned to the binary_header fields in sequential order, and missing fields are assigned None.
-            **kwargs (int): An optional key-value mapping of arguments, which overwrite any values from *args.
-            raw_header (bytes | None): Optional raw header.            
-        """
-        for i, field in enumerate(BinaryHeader.FIELDS):
-            val = args[i] if i < len(args) else None
-            val = kwargs[field] if field in kwargs else val
-            setattr(self, field, val)
-        self.raw_header = raw_header
-
-    def into_proto(self):
-        return pBinaryHeader(
-            traces=self.traces,
-            trace_data_type=self.trace_data_type,
-            fixed_length_traces=self.fixed_length_traces,
-            segy_revision=self.segy_revision,
-            auxtraces=self.auxtraces,
-            interval=self.interval,
-            interval_original=self.interval_original,
-            samples=self.samples,
-            samples_original=self.samples_original,
-            ensemble_fold=self.ensemble_fold,
-            vertical_sum=self.vertical_sum,
-            trace_type_sorting_code=self.trace_type_sorting_code,
-            sweep_type_code=self.sweep_type_code,
-            sweep_frequency_start=self.sweep_frequency_start,
-            sweep_frequency_end=self.sweep_frequency_end,
-            sweep_length=self.sweep_length,
-            sweep_channel=self.sweep_channel,
-            sweep_taper_start=self.sweep_taper_start,
-            sweep_taper_end=self.sweep_taper_end,
-            sweep_taper_type=self.sweep_taper_type,
-            correlated_traces=self.correlated_traces,
-            amplitude_recovery=self.amplitude_recovery,
-            original_measurement_system=self.original_measurement_system,
-            impulse_signal_polarity=self.impulse_signal_polarity,
-            vibratory_polarity_code=self.vibratory_polarity_code,
-            raw_header=self.raw_header,
-        )
+    from cognite.seismic._api.shims import Identifier
 
 
 class SeismicAPI(API):
@@ -162,18 +34,18 @@ class SeismicAPI(API):
         name: MaybeString = None,
         partition_identifier: Union[int, str],
         seismic_store_id: int,
-        volumedef: Union[str, None] = None,
-        geometry: Union[Geometry, None] = None,
-        metadata: Union[Metadata, None] = None,
-        text_header: Union[TextHeader, None] = None,
-        binary_header: Union[BinaryHeader, None] = None,
+        volumedef: Optional[str] = None,
+        geometry: Optional[Geometry] = None,
+        metadata: Optional[Metadata] = None,
+        text_header: Optional[TextHeader] = None,
+        binary_header: Optional[BinaryHeader] = None,
     ) -> Seismic:
         """Create a new Seismic.
         
         If neither volumedef nor geometry are specified, the new Seismic will be able to access the entire seismic store it is derived from.
 
         Args:
-            externaL_id (str): The external id of the new Seismic
+            external_id (str): The external id of the new Seismic
             name (str | None): (Optional) If specified, the name of the new Seismic
             partition_identifier (int | str): Either the partition id or external_id that the Seismic is part of
             seismic_store_id (int): The seismic store that the new Seismic is derived from
@@ -183,7 +55,7 @@ class SeismicAPI(API):
             binary_header (BinaryHeader | None): (Optional) If specified, sets the provided binary header on the new seismic
 
         Returns:
-            Seismic: The newly created Seismic with minimal data. Use search() to retrieve all data.
+            Seismic: The newly created Seismic with minimal data. Use search() or get() to retrieve all data.
         """
         if type(partition_identifier) == int:
             identifier = Identifier(id=partition_identifier)
@@ -210,13 +82,13 @@ class SeismicAPI(API):
         if binary_header is not None:
             request.binary_header.MergeFrom(binary_header.into_proto())
 
-        return self.query.CreateSeismic(request, metadata=self.metadata)
+        return Seismic.from_proto(self.query.CreateSeismic(request, metadata=self.metadata))
 
     def search(
         self,
         mode: str = "seismic",
         *,
-        id: Union[int, None] = None,
+        id: Optional[int] = None,
         external_id: MaybeString = None,
         external_id_substring: MaybeString = None,
         name: MaybeString = None,
@@ -275,7 +147,8 @@ class SeismicAPI(API):
         req.include_seismic_store = include_seismic_store
         req.include_partition = include_partition
 
-        return self.query.SearchSeismics(req, metadata=self.metadata)
+        results = self.query.SearchSeismics(req, metadata=self.metadata)
+        return [Seismic.from_proto(s) for s in results]
 
     def list(self) -> Iterable[Seismic]:
         return self.search(get_all=True)
@@ -310,7 +183,6 @@ class SeismicAPI(API):
         ]
 
         if len(result) > 1:
-            print(result)
             raise Exception("Multiple seismics found. Please contact support")
         elif len(result) == 0:
             if id is not None:
@@ -349,7 +221,7 @@ class SeismicAPI(API):
         if metadata is not None:
             request.metadata.MergeFrom(OptionalMap(data=metadata))
 
-        return self.query.EditSeismic(request, metadata=self.metadata)
+        return Seismic.from_proto(self.query.EditSeismic(request, metadata=self.metadata))
 
     def delete(self, *, id: Union[int, None] = None, external_id: MaybeString = None) -> bool:
         """Delete a seismic
